@@ -393,7 +393,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param scope: -
         :param id: -
         '''
-        jsii.create(Node, self, [host, scope, id])
+        jsii.create(self.__class__, self, [host, scope, id])
 
     @jsii.member(jsii_name="of") # type: ignore[misc]
     @builtins.classmethod
@@ -876,7 +876,7 @@ class Construct(metaclass=jsii.JSIIMeta, jsii_type="constructs.Construct"):
         '''
         options = ConstructOptions(node_factory=node_factory)
 
-        jsii.create(Construct, self, [scope, id, options])
+        jsii.create(self.__class__, self, [scope, id, options])
 
     @jsii.member(jsii_name="onPrepare")
     def _on_prepare(self) -> None:
